# fedocal messages

A schema package for [fedocal](https://pagure.io/fedocal).

See the [detailed documentation](https://fedora-messaging.readthedocs.io/en/latest/messages.html)
on packaging your schemas.
